=======
pynetcf
=======

This is the documentation of **pynetcf**.

Basic python classes that map to netCDF files on disk written according
to the `Climate and Forecast metadata conventions <http://cfconventions.org/Data/cf-conventions/cf-conventions-1.6/build/cf-conventions.html>`_

This is a first draft which has a lot of room for improvements, this is especially true for the time series based representations.

How to use
==========

For now please see the tests for examples on how to use the classes.

Contents
========

.. toctree::
   :maxdepth: 2

   License <license>
   Module Reference <_rst/modules>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
